(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38269,       1024]*)
(*NotebookOutlinePosition[     38960,       1048]*)
(*  CellTagsIndexPosition[     38916,       1044]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["sumSimplifyKD", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["sumSimplifyKD[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["]", "MR"],
  " simplifies sums. In particular, it correctly handles KroneckerDelta \
functions."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["sumSimplifyKD", "MR"],
  " also splits sums over several indexes into sums over only those indexes \
that feature in the addends."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["sum",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumThread",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumExpand",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumCollect",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumFullSimplify",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumAbstractIndex",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumNameIndex",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell["Load sneg and declare some quantities.", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(snegfermionoperators[c]\), "\n", 
    \(snegfreeindexes[k, k1, \[Sigma]]\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  "Handle ",
  ButtonBox["KroneckerDelta",
    ButtonStyle->"RefGuideLink"],
  " function"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sum[
      KroneckerDelta[k, k1]\ nc[c[CR, k], c[AN, k1]], {k, 
        k1}]\), "\[IndentingNewLine]", 
    \(sumSimplifyKD[%]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], " ", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_k\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {k}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_k1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {k1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", \({k, k1}\)}], "]"}]], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_k1\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_k1\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", \({k1}\)}], "]"}]], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "In this case, the expression needs to be expanded first using ",
  ButtonBox["sumExpand",
    ButtonStyle->"AddOnsLink"],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(expr = 
      nc[sum[number[c[], \[Sigma]], {\[Sigma]}], 
        sum[number[c[], \[Sigma]], {\[Sigma]}]]\), "\[IndentingNewLine]", 
    \(\(\(sumSimplifyKD[%]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(sumExpand[expr]\), "\[IndentingNewLine]", 
    \(sumSimplifyKD[%]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 
                        0.0]]&)], \(\[Sigma]  \[Sigma]1\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]1}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", \({\[Sigma], \[Sigma]1}\)}], 
      "]"}]], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 
                        0.0]]&)], \(\[Sigma]  \[Sigma]1\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]1}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", \({\[Sigma], \[Sigma]1}\)}], 
      "]"}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    RowBox[{
      RowBox[{"sum", "[", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 
                        0.0]]&)], \(\[Sigma]  \[Sigma]1\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {\[Sigma]1}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ",", \({\[Sigma], \[Sigma]1}\)}], "]"}], 
      "-", 
      RowBox[{"sum", "[", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], ",", \({\[Sigma], \[Sigma]1}\)}], 
        "]"}]}]], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    RowBox[{
      RowBox[{"sum", "[", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], ",", \({\[Sigma]1}\)}], "]"}], "-", 
      RowBox[{"sum", "[", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\("\[Dagger]"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\_\[Sigma]1\%\(\*"\<\"\"\>"\)\),
                  Subsuperscript[ c, 
                    RowBox[ {\[Sigma]1}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], ",", \({\[Sigma], \[Sigma]1}\)}], 
        "]"}]}]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["Splitting into several sums", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sum[f[k]\ number[c[k1], UP], {k, k1}]\), "\[IndentingNewLine]", 
    \(sumSimplifyKD[%]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{\(f[k]\), " ", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", \({k, k1}\)}], "]"}]], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    RowBox[{\(sum[f[k], {k}]\), " ", 
      RowBox[{"sum", "[", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], ",", \({k1}\)}], "]"}]}]], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sum[number[c[k]] + number[c[k1]], {k, k1}]\), "\[IndentingNewLine]", 
    \(sumSimplifyKD[%]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ",", \({k, k1}\)}], "]"}]], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(sum[1, {k1}]\), " ", 
        RowBox[{"sum", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ",", \({k}\)}], "]"}]}], "+", 
      RowBox[{\(sum[1, {k}]\), " ", 
        RowBox[{"sum", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ",", \({k1}\)}], "]"}]}]}]], "Output",
  CellLabel->"Out[13]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{591, 599},
WindowMargins->{{Automatic, 296}, {Automatic, 205}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 38, "ObjectName"],
Cell[1814, 55, 226, 7, 48, "Usage"],
Cell[2043, 64, 198, 5, 40, "Notes"],
Cell[2244, 71, 529, 23, 40, "Notes"],

Cell[CellGroupData[{
Cell[2798, 98, 42, 0, 38, "ExampleSection"],
Cell[2843, 100, 61, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2929, 104, 183, 4, 58, "Input"],
Cell[3115, 110, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3233, 115, 125, 5, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3383, 124, 185, 5, 42, "Input"],
Cell[3571, 131, 1386, 37, 33, "Output"],
Cell[4960, 170, 866, 24, 33, "Output"]
}, Open  ]],
Cell[5841, 197, 165, 5, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[6031, 206, 349, 8, 90, "Input"],
Cell[6383, 216, 3281, 83, 33, "Output"],
Cell[9667, 301, 3281, 83, 33, "Output"],
Cell[12951, 386, 3375, 86, 33, "Output"],
Cell[16329, 474, 2776, 71, 33, "Output"]
}, Open  ]],
Cell[19120, 548, 50, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[19195, 552, 147, 3, 42, "Input"],
Cell[19345, 557, 1855, 46, 33, "Output"],
Cell[21203, 605, 1862, 46, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23102, 656, 152, 3, 42, "Input"],
Cell[23257, 661, 7019, 174, 33, "Output"],
Cell[30279, 837, 7950, 182, 58, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

