(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22048,        674]*)
(*NotebookOutlinePosition[     22739,        698]*)
(*  CellTagsIndexPosition[     22695,        694]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["vc", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["vc[", "MR"],
  StyleBox["...", "IT"],
  StyleBox["]", "MR"],
  "is a wrapper (vector) that holds the information about the occupancy of \
the individual sites in the occupation number representation."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] Function ",
  ButtonBox["vacuum",
    ButtonStyle->"AddOnsLink"],
  " returns the ",
  StyleBox["vc", "MR"],
  " vector of all zeros."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["vc", "MR"],
  " objects are usually manipulated using function ",
  ButtonBox["ap",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["basis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["makebasis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["op2ndx",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ndx2op",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["goodopQ",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["vacuum",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ap",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["vc2ops",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell["Load sneg and declare some quantities", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c, d];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  "Construct a basis for two lattice sites ",
  StyleBox["c", "IT"],
  " and ",
  StyleBox["d", "IT"],
  ", and obtain the vacuum state"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(makebasis[{c[], d[]}]\), "\[IndentingNewLine]", 
    \(vac = vacuum[]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["Vaccum state internal representation", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[vac]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(vc[0, 0, 0, 0]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[5]//FullForm="]
}, Open  ]],

Cell["Single-particle states and multi-particle states", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p1 = ap[c[CR, UP], vac]\), "\[IndentingNewLine]", 
    \(FullForm[%]\), "\[IndentingNewLine]", 
    \(p12 = ap[nc[c[CR, UP], c[CR, DO]], vac]\), "\[IndentingNewLine]", 
    \(FullForm[%]\), "\[IndentingNewLine]", 
    \(p14 = ap[nc[c[CR, UP], d[CR, DO]], vac]\), "\[IndentingNewLine]", 
    \(FullForm[%]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    TagBox[
      StyleBox[\(vc[1, 0, 0, 0]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[7]//FullForm="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    TagBox[
      StyleBox[\(vc[1, 1, 0, 0]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[9]//FullForm="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    TagBox[
      StyleBox[\(vc[1, 0, 0, 1]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[11]//FullForm="]
}, Open  ]],

Cell["vc vectors can also contain Dirac kets", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ap[ket[a], p1]\), "\[IndentingNewLine]", 
    \(ap[ket[a], p12]\), "\[IndentingNewLine]", 
    \(ap[ket[a], p14]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftBracketingBar]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)], "a", 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)]}],
          DisplayForm], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftBracketingBar]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)], "a", 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)]}],
          DisplayForm], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          StyleBox["\<\"\[EmptyRectangle]\"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        TagBox[
          StyleBox["\<\"\[FilledRectangle]\"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftBracketingBar]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)], "a", 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[1, 0.500008, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0.5, 0]]&)]}],
          DisplayForm], 
        TagBox[
          StyleBox["\<\"\[RightAngleBracket]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[{
  ButtonBox["conj",
    ButtonStyle->"AddOnsLink"],
  " applied to a ",
  StyleBox["vc", "MR"],
  " vector returns unevaluated. Nevertheless, scalar products can be computed \
in this manner."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(conj[p1]\), "\[IndentingNewLine]", 
    \(nc[conj[p1], p1]\), "\[IndentingNewLine]", 
    \(conj[p14]\), "\[IndentingNewLine]", 
    \(\(\(nc[conj[p14], p14]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(nc[conj[p1], p14]\), "\[IndentingNewLine]", 
    \(nc[conj[p14], p1]\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    RowBox[{"conj", "[", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          TagBox[
            StyleBox["\<\"\[FilledRectangle]\"\>",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
          TagBox[
            StyleBox["\<\"\[EmptyRectangle]\"\>",
              FontColor->RGBColor[0, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
          TagBox[
            StyleBox["\<\"\[EmptyRectangle]\"\>",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
          TagBox[
            StyleBox["\<\"\[EmptyRectangle]\"\>",
              FontColor->RGBColor[0, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
          TagBox[
            StyleBox["\<\"\[RightAngleBracket]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm], "]"}]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[16]="],

Cell[BoxData[
    RowBox[{"conj", "[", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          TagBox[
            StyleBox["\<\"\[FilledRectangle]\"\>",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
          TagBox[
            StyleBox["\<\"\[EmptyRectangle]\"\>",
              FontColor->RGBColor[0, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
          TagBox[
            StyleBox["\<\"\[EmptyRectangle]\"\>",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
          TagBox[
            StyleBox["\<\"\[FilledRectangle]\"\>",
              FontColor->RGBColor[0, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
          TagBox[
            StyleBox["\<\"\[RightAngleBracket]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm], "]"}]], "Output",
  CellLabel->"Out[17]="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[18]="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[19]="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{540, 682},
WindowMargins->{{Automatic, 194}, {197, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 24, 0, 38, "ObjectName"],
Cell[1803, 55, 268, 7, 48, "Usage"],
Cell[2074, 64, 187, 7, 24, "Notes"],
Cell[2264, 73, 189, 7, 24, "Notes"],
Cell[2456, 82, 558, 26, 24, "Notes"],

Cell[CellGroupData[{
Cell[3039, 112, 42, 0, 38, "ExampleSection"],
Cell[3084, 114, 60, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3169, 118, 142, 3, 42, "Input"],
Cell[3314, 123, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3432, 128, 171, 6, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3628, 138, 128, 3, 42, "Input"],
Cell[3759, 143, 2826, 77, 33, "Output"],
Cell[6588, 222, 1234, 32, 25, "Output"]
}, Open  ]],
Cell[7837, 257, 59, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[7921, 261, 70, 2, 26, "Input"],
Cell[7994, 265, 224, 7, 38, "Output"]
}, Open  ]],
Cell[8233, 275, 71, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[8329, 279, 363, 7, 106, "Input"],
Cell[8695, 288, 1235, 32, 25, "Output"],
Cell[9933, 322, 224, 7, 38, "Output"],
Cell[10160, 331, 1236, 32, 25, "Output"],
Cell[11399, 365, 224, 7, 38, "Output"],
Cell[11626, 374, 1237, 32, 25, "Output"],
Cell[12866, 408, 225, 7, 38, "Output"]
}, Open  ]],
Cell[13106, 418, 61, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[13192, 422, 172, 4, 58, "Input"],
Cell[13367, 428, 1698, 43, 25, "Output"],
Cell[15068, 473, 1699, 43, 25, "Output"],
Cell[16770, 518, 1699, 43, 25, "Output"]
}, Open  ]],
Cell[18484, 564, 227, 7, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[18736, 575, 351, 8, 122, "Input"],
Cell[19090, 585, 1331, 33, 25, "Output"],
Cell[20424, 620, 60, 2, 25, "Output"],
Cell[20487, 624, 1332, 33, 25, "Output"],
Cell[21822, 659, 60, 2, 25, "Output"],
Cell[21885, 663, 60, 2, 25, "Output"],
Cell[21948, 667, 60, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

