(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    349164,      10189]
NotebookOptionsPosition[    345192,      10057]
NotebookOutlinePosition[    345649,      10075]
CellTagsIndexPosition[    345606,      10072]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Double quantum dot with interimpurity charge-charge repulsion term
Part of SNEG package, http://nrgljubljana.ijs.si
Rok Zitko, rok.zitko@ijs.si, March 2007\
\>", "Text",
 Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", "sneg`sneg`"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]}], "Input"],

Cell[BoxData["\<\"sneg 1.234 Copyright (C) 2013 Rok Zitko\"\>"], "Print",
 CellChangeTimes->{3.63548619478788*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"snegfermionoperators", "[", "d", "]"}], "\[IndentingNewLine]", 
 RowBox[{"snegrealconstants", "[", 
  RowBox[{"U", ",", "U12", ",", "t", ",", "\[Delta]"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H", "=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"number", "[", 
           RowBox[{"d", "[", "i", "]"}], "]"}], "-", "1"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"U", "/", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"pow", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"number", "[", 
             RowBox[{"d", "[", "i", "]"}], "]"}], "-", "1"}], ",", "2"}], 
          "]"}], ")"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "+", 
    RowBox[{"U12", " ", 
     RowBox[{"chargecharge", "[", 
      RowBox[{
       RowBox[{"d", "[", "1", "]"}], ",", 
       RowBox[{"d", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{"t", " ", 
     RowBox[{"hop", "[", 
      RowBox[{
       RowBox[{"d", "[", "1", "]"}], ",", 
       RowBox[{"d", "[", "2", "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{"H", ",", 
   RowBox[{"Cases", "[", 
    RowBox[{"H", ",", "_nc", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Infinity]"}], "}"}]}], "]"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"U", "-", 
  RowBox[{"2", " ", "\[Delta]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["U", "2"]}], "+", "\[Delta]"}], ")"}], " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["U", "2"]}], "+", "\[Delta]"}], ")"}], " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["U", "2"]}], "+", "\[Delta]"}], ")"}], " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["U", "2"]}], "+", "\[Delta]"}], ")"}], " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}]}]], "Output",
 CellChangeTimes->{3.6354861989004383`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"sx", ",", "sy", ",", "sz", ",", "stot"}], "}"}], "=", 
  RowBox[{"manyspin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "[", "1", "]"}], ",", 
     RowBox[{"d", "[", "2", "]"}]}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["3", "4"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["3", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"1", 
           TagBox[
            StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"2", 
           TagBox[
            StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"1", 
           TagBox[
            StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"2", 
           TagBox[
            StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm]}], "-", 
    RowBox[{
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"1", 
           TagBox[
            StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"2", 
           TagBox[
            StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"1", 
           TagBox[
            StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 1, 0]], 
     TagBox[
      StyleBox[
       TemplateBox[{"d",RowBox[{"2", 
           TagBox[
            StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
        "Subsuperscript"],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["3", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.635486200157682*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ox", ",", "oy", ",", "oz"}], "}"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"nc", "[", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "i", ",", "\[Mu]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
         RowBox[{"d", "[", 
          RowBox[{"AN", ",", "j", ",", "\[Mu]"}], "]"}]}], "]"}], "]"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Mu]", ",", "0", ",", "1"}], "}"}]}], "]"}], "&"}], " ", "/@", 
   RowBox[{"{", 
    RowBox[{"PauliX", ",", "PauliY", ",", "PauliZ"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"1", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
             StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
          "\"\[Dagger]\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        TemplateBox[{"d",RowBox[{"2", 
            TagBox[
             StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
         "Subsuperscript"],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.635486201028221*^9}]
}, Open  ]],

Cell["Spin and pseudo-spin operators commute!", "Text",
 CellChangeTimes->{{3.63548620265728*^9, 3.6354862036869707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"Outer", "[", " ", 
   RowBox[{"komutator", ",", 
    RowBox[{"{", 
     RowBox[{"sx", ",", "sy", ",", "sz"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"ox", ",", "oy", ",", "oz"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.635486204764736*^9}]
}, Open  ]],

Cell["Hamiltonian commutes with spin operator for any parameters.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "sx"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "sy"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "sz"}], "]"}]}]}], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6354862181658087`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.635486218316721*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.635486218496607*^9}]
}, Open  ]],

Cell["\<\
Orbital psuedo-spin operators commute with the Hamiltonian for U=U12 and t=0.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "ox"}], "]"}]}], "\n", 
 RowBox[{"%", "/.", 
  RowBox[{"U12", "\[Rule]", "U"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}]}]], "Output",
 CellChangeTimes->{3.635486220704595*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.635486220730885*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "oy"}], "]"}]}], "\n", 
 RowBox[{"%", "/.", 
  RowBox[{"U12", "\[Rule]", "U"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "U12", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}]}]], "Output",
 CellChangeTimes->{3.635486223929604*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}]}]], "Output",
 CellChangeTimes->{3.635486223964013*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6354862239700413`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Expand", " ", "@", " ", 
  RowBox[{"komutator", "[", 
   RowBox[{"H", ",", "oz"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "t"}], " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "-", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
           StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"2", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
       
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 1, 0]], 
    TagBox[
     StyleBox[
      TemplateBox[{"d",RowBox[{"1", 
          TagBox[
           StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
           StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
       "Subsuperscript"],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}]}]}]], "Output",
 CellChangeTimes->{3.635486225766982*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.635486225776825*^9}]
}, Open  ]],

Cell["Hamiltonian without hopping for U12=U.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"H2", "=", 
   RowBox[{"H", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "\[Rule]", "0"}], ",", 
      RowBox[{"U12", "\[Rule]", "U"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pdt", "=", 
  RowBox[{
   RowBox[{"Outer", "[", 
    RowBox[{"nc", ",", 
     RowBox[{"{", 
      RowBox[{"sx", ",", "sy", ",", "sz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ox", ",", "oy", ",", "oz"}], "}"}]}], "]"}], "//", 
   "Expand"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],
            "\"\[Dagger]\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"1", 
              TagBox[
               StyleBox[
               "\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
               StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          TemplateBox[{"d",RowBox[{"2", 
              TagBox[
               StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
               StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\""},
           "Subsuperscript"],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6354862279827757`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Hamiltonian", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"for", " ", "U12"}], "=", 
    RowBox[{
     RowBox[{"U", " ", "and", " ", "t"}], "=", "0"}]}], ")"}], " ", 
  "commutes", " ", "with", " ", "direct", " ", "product", " ", "operators", 
  " ", 
  SubscriptBox["S", "i"], 
  SubscriptBox["O", "j"]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Expand", " ", "@", " ", 
     RowBox[{"komutator", "[", 
      RowBox[{"H2", ",", "#"}], "]"}]}], "&"}], ",", 
   RowBox[{"Flatten", "[", "pdt", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.635486238581451*^9}]
}, Open  ]],

Cell["We add factors of 2 to simplify matrices", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"2", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sx", ",", "sy", ",", "sz"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ox", ",", "oy", ",", "oz"}], "}"}], ",", 
      RowBox[{"2", 
       RowBox[{"Flatten", "[", "pdt", "]"}]}]}], "]"}]}]}], ";"}]], "Input"],

Cell["\<\
Defining SU(4) quadruplet representation. (cf Georgi, p. 114)\
\>", "Text",
 CellChangeTimes->{{3.635486245706624*^9, 3.6354862472645597`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"quadruplet", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", 
    RowBox[{"d", "[", 
     RowBox[{"CR", ",", "1", ",", "DO"}], "]"}], ",", 
    RowBox[{"d", "[", 
     RowBox[{"CR", ",", "2", ",", "UP"}], "]"}], ",", 
    RowBox[{"d", "[", 
     RowBox[{"CR", ",", "2", ",", "DO"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TemplateBox[{"d",RowBox[{"1", 
         TagBox[
          StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
          StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
      "Subsuperscript"],
     ScriptSizeMultipliers->1,
     ScriptBaselineShifts->{1, 1}],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TemplateBox[{"d",RowBox[{"1", 
         TagBox[
          StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
          StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
      "Subsuperscript"],
     ScriptSizeMultipliers->1,
     ScriptBaselineShifts->{1, 1}],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TemplateBox[{"d",RowBox[{"2", 
         TagBox[
          StyleBox["\"\[DoubleUpArrow]\"", FontColor -> RGBColor[1, 0, 0]], 
          StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}],"\"\[Dagger]\""},
      "Subsuperscript"],
     ScriptSizeMultipliers->1,
     ScriptBaselineShifts->{1, 1}],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TemplateBox[{"d",RowBox[{"2", 
         TagBox[
          StyleBox["\"\[DownArrow]\"", FontColor -> RGBColor[0, 0, 1]], 
          StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}],"\"\[Dagger]\""},
      "Subsuperscript"],
     ScriptSizeMultipliers->1,
     ScriptBaselineShifts->{1, 1}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.63548624807961*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"braketop", "[", 
    RowBox[{"a_", ",", "op_", ",", "b_"}], "]"}], ":=", 
   RowBox[{"scalarproductop", "[", 
    RowBox[{"a", ",", 
     RowBox[{"nc", "[", 
      RowBox[{"op", ",", "b"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"braketop", "[", 
  RowBox[{"1", ",", "1", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"braketop", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", "1", ",", 
   RowBox[{"d", "[", 
    RowBox[{"CR", ",", "1", ",", "UP"}], "]"}]}], "]"}]}], "Input"],

Cell[BoxData["1"], "Output"],

Cell[BoxData["1"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", " ", "@", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"braketop", "[", 
       RowBox[{
        RowBox[{"quadruplet", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "#", ",", 
        RowBox[{"quadruplet", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "4"}], "}"}]}], "]"}]}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"2", "sx"}], ",", 
    RowBox[{"2", "sy"}], ",", 
    RowBox[{"2", "sz"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", "1"},
       {"0", "0", "1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0", "0"},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"0", "0", "\[ImaginaryI]", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", "1", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MatrixForm", " ", "@", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"braketop", "[", 
       RowBox[{
        RowBox[{"quadruplet", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "#", ",", 
        RowBox[{"quadruplet", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "4"}], "}"}]}], "]"}]}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"2", "ox"}], ",", 
    RowBox[{"2", "oy"}], ",", 
    RowBox[{"2", "oz"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "1", "0"},
       {"0", "0", "0", "1"},
       {"1", "0", "0", "0"},
       {"0", "1", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", "\[ImaginaryI]", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", "0"},
       {"0", "1", "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"braketop", "[", 
        RowBox[{
         RowBox[{"quadruplet", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "#", ",", 
         RowBox[{"quadruplet", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "4"}], "}"}]}], "]"}], "&"}], "/@", "t"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", " ", "/@", " ", "m"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", "1"},
       {"0", "0", "1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0", "0"},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"0", "0", "\[ImaginaryI]", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", "1", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "1", "0"},
       {"0", "0", "0", "1"},
       {"1", "0", "0", "0"},
       {"0", "1", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", "\[ImaginaryI]", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", "0"},
       {"0", "1", "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "1"},
       {"0", "0", "1", "0"},
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0"},
       {"0", "\[ImaginaryI]", "0", "0"},
       {"\[ImaginaryI]", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"0", "0", "\[ImaginaryI]", "0"},
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0", "0"},
       {"\[ImaginaryI]", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", "1", "0"},
       {"0", "1", "0", "0"},
       {
        RowBox[{"-", "1"}], "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0", "0"},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", "0", "0", "\[ImaginaryI]"},
       {"0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "1", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0"},
       {"0", "0", "0", "\[ImaginaryI]"},
       {"\[ImaginaryI]", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}], "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell["Traceless matrices with det=1", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Det", ",", "m"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Tr", ",", "m"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Outer", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"#1", ".", "#2"}], "]"}], "&"}], ",", "m", ",", "m", ",", "1"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "4", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "4", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "4", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "4", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "4", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "4", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "4", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "4",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "4", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "4", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "4", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "4", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "4", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "4", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "4"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 3}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->False,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 5}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sextuplet", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nc", "[", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", 
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "2", ",", "UP"}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"nc", "[", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", 
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "2", ",", "DO"}], "]"}]}], "]"}], "+", 
       RowBox[{"nc", "[", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "1", ",", "DO"}], "]"}], ",", 
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "2", ",", "UP"}], "]"}]}], "]"}]}], ")"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"nc", "[", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "1", ",", "DO"}], "]"}], ",", 
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "2", ",", "DO"}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"nc", "[", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", 
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "1", ",", "DO"}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"nc", "[", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "1", ",", "UP"}], "]"}], ",", 
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "2", ",", "DO"}], "]"}]}], "]"}], "-", 
       RowBox[{"nc", "[", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "1", ",", "DO"}], "]"}], ",", 
         RowBox[{"d", "[", 
          RowBox[{"CR", ",", "2", ",", "UP"}], "]"}]}], "]"}]}], ")"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"nc", "[", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "2", ",", "UP"}], "]"}], ",", 
      RowBox[{"d", "[", 
       RowBox[{"CR", ",", "2", ",", "DO"}], "]"}]}], "]"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    TagBox[
     StyleBox[
      InterpretationBox[
       SubsuperscriptBox["d", 
        RowBox[{"1", 
         TagBox[
          StyleBox["\<\"\[UpArrow]\"\>",
           FontColor->RGBColor[1, 0, 0]],
          
          StyleForm[#, FontColor -> 
           RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
       Subsuperscript[d, 
        RowBox[{1, 
          StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
        "\[Dagger]"],
       Editable->False],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 0.392187, 0]], 
    TagBox[
     StyleBox[
      InterpretationBox[
       SubsuperscriptBox["d", 
        RowBox[{"2", 
         TagBox[
          StyleBox["\<\"\[UpArrow]\"\>",
           FontColor->RGBColor[1, 0, 0]],
          
          StyleForm[#, FontColor -> 
           RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
       Subsuperscript[d, 
        RowBox[{2, 
          StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
        "\[Dagger]"],
       Editable->False],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{1, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[UpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{2, 
            StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[UpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{1, 
            StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], 
    SqrtBox["2"]], ",", 
   RowBox[{
    TagBox[
     StyleBox[
      InterpretationBox[
       SubsuperscriptBox["d", 
        RowBox[{"1", 
         TagBox[
          StyleBox["\<\"\[DownArrow]\"\>",
           FontColor->RGBColor[0, 0, 1]],
          
          StyleForm[#, FontColor -> 
           RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
       Subsuperscript[d, 
        RowBox[{1, 
          StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
        "\[Dagger]"],
       Editable->False],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm], 
    StyleBox["\[CenterDot]",
     FontColor->RGBColor[0, 0.392187, 0]], 
    TagBox[
     StyleBox[
      InterpretationBox[
       SubsuperscriptBox["d", 
        RowBox[{"2", 
         TagBox[
          StyleBox["\<\"\[DownArrow]\"\>",
           FontColor->RGBColor[0, 0, 1]],
          
          StyleForm[#, FontColor -> 
           RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
       Subsuperscript[d, 
        RowBox[{2, 
          StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
        "\[Dagger]"],
       Editable->False],
      ScriptSizeMultipliers->1,
      ScriptBaselineShifts->{1, 1}],
     DisplayForm]}], ",", 
   RowBox[{"\<\"-\"\>", 
    RowBox[{
     TagBox[
      StyleBox[
       InterpretationBox[
        SubsuperscriptBox["d", 
         RowBox[{"1", 
          TagBox[
           StyleBox["\<\"\[DownArrow]\"\>",
            FontColor->RGBColor[0, 0, 1]],
           
           StyleForm[#, FontColor -> 
            RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
        Subsuperscript[d, 
         RowBox[{1, 
           StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
         "\[Dagger]"],
        Editable->False],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 0.392187, 0]], 
     TagBox[
      StyleBox[
       InterpretationBox[
        SubsuperscriptBox["d", 
         RowBox[{"1", 
          TagBox[
           StyleBox["\<\"\[UpArrow]\"\>",
            FontColor->RGBColor[1, 0, 0]],
           
           StyleForm[#, FontColor -> 
            RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
        Subsuperscript[d, 
         RowBox[{1, 
           StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
         "\[Dagger]"],
        Editable->False],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm]}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"\<\"-\"\>", 
      RowBox[{
       TagBox[
        StyleBox[
         InterpretationBox[
          SubsuperscriptBox["d", 
           RowBox[{"1", 
            TagBox[
             StyleBox["\<\"\[DownArrow]\"\>",
              FontColor->RGBColor[0, 0, 1]],
             
             StyleForm[#, FontColor -> 
              RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
          Subsuperscript[d, 
           RowBox[{1, 
             StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
           "\[Dagger]"],
          Editable->False],
         ScriptSizeMultipliers->1,
         ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
       StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
       TagBox[
        StyleBox[
         InterpretationBox[
          SubsuperscriptBox["d", 
           RowBox[{"2", 
            TagBox[
             StyleBox["\<\"\[UpArrow]\"\>",
              FontColor->RGBColor[1, 0, 0]],
             
             StyleForm[#, FontColor -> 
              RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
          Subsuperscript[d, 
           RowBox[{2, 
             StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
           "\[Dagger]"],
          Editable->False],
         ScriptSizeMultipliers->1,
         ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[UpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{1, 
            StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["d", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[d, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], 
    SqrtBox["2"]], ",", 
   RowBox[{"\<\"-\"\>", 
    RowBox[{
     TagBox[
      StyleBox[
       InterpretationBox[
        SubsuperscriptBox["d", 
         RowBox[{"2", 
          TagBox[
           StyleBox["\<\"\[DownArrow]\"\>",
            FontColor->RGBColor[0, 0, 1]],
           
           StyleForm[#, FontColor -> 
            RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
        Subsuperscript[d, 
         RowBox[{2, 
           StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
         "\[Dagger]"],
        Editable->False],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm], 
     StyleBox["\[CenterDot]",
      FontColor->RGBColor[0, 0.392187, 0]], 
     TagBox[
      StyleBox[
       InterpretationBox[
        SubsuperscriptBox["d", 
         RowBox[{"2", 
          TagBox[
           StyleBox["\<\"\[UpArrow]\"\>",
            FontColor->RGBColor[1, 0, 0]],
           
           StyleForm[#, FontColor -> 
            RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
        Subsuperscript[d, 
         RowBox[{2, 
           StyleForm["\[UpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
         "\[Dagger]"],
        Editable->False],
       ScriptSizeMultipliers->1,
       ScriptBaselineShifts->{1, 1}],
      DisplayForm]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"braketop", "[", 
        RowBox[{
         RowBox[{"sextuplet", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "#", ",", 
         RowBox[{"sextuplet", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "6"}], "}"}]}], "]"}], "&"}], "/@", "t"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", " ", "/@", " ", "m"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        SqrtBox["2"], "0", "0", "0", "0"},
       {
        SqrtBox["2"], "0", 
        SqrtBox["2"], "0", "0", "0"},
       {"0", 
        SqrtBox["2"], "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["2"]}], "0", "0", "0", "0"},
       {
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}], "0", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["2"]}], "0", "0", "0"},
       {"0", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}], "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"2", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", 
        RowBox[{"-", "2"}], "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", 
        SqrtBox["2"], "0"},
       {"0", "0", "0", 
        SqrtBox["2"], "0", 
        SqrtBox["2"]},
       {"0", "0", "0", "0", 
        SqrtBox["2"], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}], "0", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["2"]}]},
       {"0", "0", "0", "0", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["2"]}], "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "2", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", 
        RowBox[{"-", "2"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Det", ",", "m"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Tr", ",", "m"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Outer", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"#1", ".", "#2"}], "]"}], "&"}], ",", "m", ",", "m", ",", "1"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "8", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "8", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "8", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "8", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "8", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "8", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{871, 880},
WindowMargins->{{Automatic, 101}, {Automatic, 74}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 213, 5, 84, "Text"],
Cell[CellGroupData[{
Cell[796, 29, 185, 5, 46, "Input"],
Cell[984, 36, 114, 1, 22, "Print"]
}, Open  ]],
Cell[1113, 40, 198, 3, 46, "Input"],
Cell[CellGroupData[{
Cell[1336, 47, 1227, 39, 63, "Input"],
Cell[2566, 88, 16904, 519, 111, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19507, 612, 268, 8, 28, "Input"],
Cell[19778, 622, 28377, 824, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48192, 1451, 924, 28, 63, "Input"],
Cell[49119, 1481, 10879, 319, 121, "Output"]
}, Open  ]],
Cell[60013, 1803, 122, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[60160, 1808, 271, 7, 28, "Input"],
Cell[60434, 1817, 302, 9, 28, "Output"]
}, Open  ]],
Cell[60751, 1829, 75, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[60851, 1833, 379, 9, 63, "Input"],
Cell[61233, 1844, 72, 1, 28, "Output"],
Cell[61308, 1847, 70, 1, 28, "Output"],
Cell[61381, 1850, 70, 1, 28, "Output"]
}, Open  ]],
Cell[61466, 1854, 103, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[61594, 1861, 192, 5, 46, "Input"],
Cell[61789, 1868, 26956, 819, 232, "Output"],
Cell[88748, 2689, 70, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88855, 2695, 272, 7, 63, "Input"],
Cell[89130, 2704, 30620, 918, 232, "Output"],
Cell[119753, 3624, 3404, 102, 39, "Output"],
Cell[123160, 3728, 72, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123269, 3734, 207, 5, 46, "Input"],
Cell[123479, 3741, 3335, 103, 39, "Output"],
Cell[126817, 3846, 70, 1, 28, "Output"]
}, Open  ]],
Cell[126902, 3850, 54, 0, 30, "Text"],
Cell[126959, 3852, 212, 7, 28, "Input"],
Cell[CellGroupData[{
Cell[127196, 3863, 285, 9, 28, "Input"],
Cell[127484, 3874, 161626, 4491, 1009, "Output"]
}, Open  ]],
Cell[289125, 8368, 341, 10, 32, "Text"],
Cell[CellGroupData[{
Cell[289491, 8382, 242, 7, 28, "Input"],
Cell[289736, 8391, 192, 5, 28, "Output"]
}, Open  ]],
Cell[289943, 8399, 56, 0, 30, "Text"],
Cell[290002, 8401, 354, 11, 28, "Input"],
Cell[290359, 8414, 153, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[290537, 8421, 397, 11, 28, "Input"],
Cell[290937, 8434, 1482, 43, 75, "Output"]
}, Open  ]],
Cell[292434, 8480, 271, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[292730, 8492, 323, 8, 46, "Input"],
Cell[293056, 8502, 28, 0, 28, "Output"],
Cell[293087, 8504, 28, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293152, 8509, 639, 20, 46, "Input"],
Cell[293794, 8531, 2228, 63, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[296059, 8599, 639, 20, 46, "Input"],
Cell[296701, 8621, 2228, 63, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298966, 8689, 612, 18, 46, "Input"],
Cell[299581, 8709, 11072, 311, 239, "Output"]
}, Open  ]],
Cell[310668, 9023, 45, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[310738, 9027, 81, 2, 28, "Input"],
Cell[310822, 9031, 213, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311072, 9041, 80, 2, 28, "Input"],
Cell[311155, 9045, 213, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311405, 9055, 182, 6, 28, "Input"],
Cell[311590, 9063, 3128, 77, 139, "Output"]
}, Open  ]],
Cell[314733, 9143, 274, 9, 10, "Text"],
Cell[CellGroupData[{
Cell[315032, 9156, 2259, 67, 123, "Input"],
Cell[317294, 9225, 10465, 339, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327796, 9569, 610, 18, 43, "Input"],
Cell[328409, 9589, 12750, 347, 529, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341196, 9941, 81, 2, 27, "Input"],
Cell[341280, 9945, 213, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341530, 9955, 80, 2, 27, "Input"],
Cell[341613, 9959, 213, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341863, 9969, 182, 6, 27, "Input"],
Cell[342048, 9977, 3128, 77, 139, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

